==> rospell-2006.01.tar.gz: rospell-2006.01/src/rospell/qtutils.h <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#ifndef QTUTILS_H
#define QTUTILS_H

#include <qstring.h>
#include <qapplication.h>
#ifdef USING_QT3
#include <qmultilineedit.h>
#endif
#ifdef USING_QT4
#include <q3multilineedit.h>
#endif



//#include <stdio.h>
//#include <stdlib.h>
//#include <ctype.h>
#include "debug.h"

class QTUTILS {
	static const int PROG_BUF = 10000;
public:
	static void run_program(QString program, Q3MultiLineEdit *wdg, char *termination_string = 0) {
		PROFILE("QT_UTILS::run_program");
		FILE *input;
		char buf[PROG_BUF + 1];
		char *out;

		if (0 == (input = popen(program, "r")))
			return;
			
		else {
			while ((out = fgets(buf, PROG_BUF, input)) != 0) {
				printf("%s", buf);
				LOG("QT_UTILS::run_program: len %d", strlen(buf));
				wdg->insertLine(QString(buf));
				wdg->update();
				qApp->processEvents();
			}

			pclose(input);
		}
		
		if (termination_string)
			wdg->insertLine(QString(termination_string));

	}
};
#endif

==> rospell-2007.00.tar.gz: rospell-2007.00/src/rospell/qtutils.h <==
//****************************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//****************************************************************************

#ifndef QTUTILS_H
#define QTUTILS_H

#include <qapplication.h>
#ifdef USING_QT3
#include <qmultilineedit.h>
#endif
#ifdef USING_QT4
#include <q3multilineedit.h>
#endif



#include "debug.h"

class QTUTILS {
	static const int PROG_BUF = 10000;
public:
	static void run_program(QString program, Q3MultiLineEdit *wdg, char *termination_string = 0) {
		PROFILE("QT_UTILS::run_program");
		FILE *input;
		char buf[PROG_BUF + 1];
		char *out;

		if (0 == (input = popen(program, "r")))
			return;
			
		else {
			while ((out = fgets(buf, PROG_BUF, input)) != 0) {
				printf("%s", buf);
				LOG("QT_UTILS::run_program: len %d", strlen(buf));
				wdg->insertLine(QString::fromUtf8(buf));
				wdg->update();
				qApp->processEvents();
			}

			pclose(input);
		}
		
		if (termination_string)
			wdg->insertLine(QString(termination_string));

	}
};
#endif
